Export Package VRC : bcB40Mc4cn24
Update compared VRC:   B40 c4cn24
Only Package       : Yes
Based on sessions  : No
Script sources     : No
Function  sources  : No
Library sources    : No
---------------------------------------
C = Charts
q = Questions
c = Messages
l = Labels
d = Domains
t = Table Definitions
s = Sessions
p = Scripts
o = Objects
f = Forms
F = Form Dumps
m = Menus
M = Menu Dumps
r = Reports
i = Impl. Functions
b = Functions
h = Help Text Codes
----------------------
pbccnv0200                          B40Mc4cn24 (without source)
pbccnvvtest                         B40Mc4cn24 (without source)
pbcgct0100                          B40Mc4cn24 (without source)
pbcgct0106                          B40Mc4cn24 (without source)
pbcgct91881                         B40Mc4cn24 (without source)
pbcgctexport                        B40Mc4cn24 (without source)
pbcgcthistory                       B40Mc4cn24 (without source)
pbcgctimport                        B40Mc4cn24 (without source)
pbcrun9087                          B40Mc4cn24 (without source)
pbcrunconvdll                       B40Mc4cn24 (without source)
pbcrunfill.988                      B40Mc4cn24 (without source)
pbcruninitrep                       B40Mc4cn24 (without source)
cbcbcgct0106.01                     B40Mc4cn24
obccnv0200                          B40Mc4cn24
obcgct0100                          B40Mc4cn24
obcgct0106                          B40Mc4cn24
obcgct91881                         B40Mc4cn24
obcgctexport                        B40Mc4cn24
obcgcthistory                       B40Mc4cn24
obcgctimport                        B40Mc4cn24
obcrun9087                          B40Mc4cn24
obcrunconvdll                       B40Mc4cn24
obcrunfill.988                      B40Mc4cn24
obcruninitrep                       B40Mc4cn24
obcsql3272                          B40Mc4cn24
